# SKFlow

## Original code

[https://github.com/littlespray/SKFlow](https://github.com/littlespray/SKFlow)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
@InProceedings{Sun2022SKFlowLearningOptical,
  author    = {Shangkun Sun and Yuanqi Chen and Y. Zhu and Guodong Guo and Gezhong Li},
  booktitle = {NeurIPS},
  title     = {SKFlow: Learning Optical Flow with Super Kernels},
  year      = {2022},
}
```